import torch
import torchvision.transforms as transforms
from PIL import Image
from lenet5 import Lenet5
import cv2
# 加载预训练的模型
model = Lenet5()
model.load_state_dict(torch.load('lenet5.pt'))
model.eval()


# 图像预处理
transform = transforms.Compose([
    transforms.Resize((150, 150)),
    transforms.Grayscale(),
    transforms.ToTensor(),
    transforms.Normalize(mean=[0.485], std=[0.229])
])

# 加载要预测的图像
image_path = 'm1.jpg'
img = cv2.imread(image_path)

# img = cv2.resize(img, (300, 200))

img = Image.fromarray(img)
img = transform(img)



# 将图片转换为适合模型输入的张量形状
img = img.unsqueeze(0)

# 使用GPU进行预测（如果可用）
device = torch.device("cuda" if torch.cuda.is_available() else "cpu")
model = model.to(device)
img = img.to(device)

# 进行预测
with torch.no_grad():
    output = model(img)
    probabilities = torch.softmax(output, dim=1)  # 对预测结果进行softmax操作

# 获取预测结果
_, predicted = torch.max(output, 1)
class_names = ['布', '石头', '剪刀']
predicted_class = class_names[predicted.item()]
predicted_probabilities = probabilities[0].tolist()  # 将概率张量转换为Python列表


print("预测结果:", predicted_class)
print("预测概率:", predicted_probabilities)
